---
feature_story: FS_39_58_01_91
feature_title: query cache
feature_status: DONE
---

The initial commit with LRU cache:
https://github.com/argrelay/argrelay/commit/dce699a99355f84a85923141c4e10b5d7fadd2aa

TODO: provide details.
